@@ -11,28 +11,26 @@ BWlCpp <- function(x, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE, theta =
     .Call(Cpp_BWl, x, ng, g, gs, w, narm, theta, set_mean, B, fill)
 }
 
-TRACpp <- function(x, xAG, g = 0L, ret = 1L) {
-    .Call(Cpp_TRA, x, xAG, g, ret)
+TRAC <- function(x, xAG, g = 0L, ret = 1L, set = FALSE, ...) {
+  if(!missing(...)) unused_arg_action(match.call(), ...)
+  if(set) return(invisible(.Call(C_TRA, x, xAG, g, ret, set)))
+  .Call(C_TRA, x, xAG, g, ret, set)
 }
 
-TRAmCpp <- function(x, xAG, g = 0L, ret = 1L) {
-    .Call(Cpp_TRAm, x, xAG, g, ret)
+TRAmC <- function(x, xAG, g = 0L, ret = 1L, set = FALSE, ...) {
+  if(!missing(...)) unused_arg_action(match.call(), ...)
+  if(set) return(invisible(.Call(C_TRAm, x, xAG, g, ret, set)))
+  .Call(C_TRAm, x, xAG, g, ret, set)
 }
 
-TRAlCpp <- function(x, xAG, g = 0L, ret = 1L) {
-    .Call(Cpp_TRAl, x, xAG, g, ret)
+TRAlC <- function(x, xAG, g = 0L, ret = 1L, set = FALSE, ...) {
+  if(!missing(...)) unused_arg_action(match.call(), ...)
+  if(set) return(invisible(.Call(C_TRAl, x, xAG, g, ret, set)))
+  .Call(C_TRAl, x, xAG, g, ret, set)
 }
 
-fndistinctCpp <- function(x, ng = 0L, g = 0L, gs = NULL, narm = TRUE) {
-    .Call(Cpp_fndistinct, x, ng, g, gs, narm)
-}
-
-fndistinctlCpp <- function(x, ng = 0L, g = 0L, gs = NULL, narm = TRUE, drop = TRUE) {
-    .Call(Cpp_fndistinctl, x, ng, g, gs, narm, drop)
-}
-
-fndistinctmCpp <- function(x, ng = 0L, g = 0L, gs = NULL, narm = TRUE, drop = TRUE) {
-    .Call(Cpp_fndistinctm, x, ng, g, gs, narm, drop)
+fndistinctC <- function(x, g = NULL, narm = TRUE, nthreads = 1L) {
+    .Call(C_fndistinct, x, g, narm, nthreads)
 }
 
 pwnobsmCpp <- function(x) {
@@ -43,14 +41,6 @@ fnobsC <- function(x, ng = 0L, g = 0L) {
     .Call(C_fnobs, x, ng, g)
 }
 
-# fnobsmC <- function(x, ng = 0L, g = 0L, drop = TRUE) {
-#     .Call(C_fnobsm, x, ng, g, drop)
-# }
-
-# fnobslC <- function(x, ng = 0L, g = 0L, drop = TRUE) {
-#     .Call(C_fnobsl, x, ng, g, drop)
-# }
-
 varyingCpp <- function(x, ng = 0L, g = 0L, any_group = TRUE) {
     .Call(Cpp_varying, x, ng, g, any_group)
 }
@@ -99,52 +89,16 @@ flagleadlCpp <- function(x, n = 1L, fill = NULL, ng = 0L, g = 0L, t = NULL, name
     .Call(Cpp_flagleadl, x, n, fill, ng, g, t, names)
 }
 
-fmeanCpp <- function(x, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE) {
-    .Call(Cpp_fmean, x, ng, g, gs, w, narm)
+fnthCpp <- function(x, n = 0.5, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE, ret = 1L, nthreads = 1L) {
+  .Call(Cpp_fnth, x, n, ng, g, gs, w, narm, ret, nthreads)
 }
 
-fmeanmCpp <- function(x, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE, drop = TRUE) {
-    .Call(Cpp_fmeanm, x, ng, g, gs, w, narm, drop)
+fnthmCpp <- function(x, n = 0.5, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE, drop = TRUE, ret = 1L, nthreads = 1L) {
+  .Call(Cpp_fnthm, x, n, ng, g, gs, w, narm, drop, ret, nthreads)
 }
 
-fmeanlCpp <- function(x, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE, drop = TRUE) {
-    .Call(Cpp_fmeanl, x, ng, g, gs, w, narm, drop)
-}
-
-fnthCpp <- function(x, n = 0.5, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE, ret = 1L) {
-  .Call(Cpp_fnth, x, n, ng, g, gs, w, narm, ret)
-}
-
-fnthmCpp <- function(x, n = 0.5, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE, drop = TRUE, ret = 1L) {
-  .Call(Cpp_fnthm, x, n, ng, g, gs, w, narm, drop, ret)
-}
-
-fnthlCpp <- function(x, n = 0.5, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE, drop = TRUE, ret = 1L) {
-  .Call(Cpp_fnthl, x, n, ng, g, gs, w, narm, drop, ret)
-}
-
-fmodeCpp <- function(x, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE, ret = 0L) {
-    .Call(Cpp_fmode, x, ng, g, gs, w, narm, ret)
-}
-
-fmodelCpp <- function(x, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE, ret = 0L) {
-    .Call(Cpp_fmodel, x, ng, g, gs, w, narm, ret)
-}
-
-fmodemCpp <- function(x, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE, drop = TRUE, ret = 0L) {
-    .Call(Cpp_fmodem, x, ng, g, gs, w, narm, drop, ret)
-}
-
-fprodCpp <- function(x, ng = 0L, g = 0L, w = NULL, narm = TRUE) {
-    .Call(Cpp_fprod, x, ng, g, w, narm)
-}
-
-fprodmCpp <- function(x, ng = 0L, g = 0L, w = NULL, narm = TRUE, drop = TRUE) {
-    .Call(Cpp_fprodm, x, ng, g, w, narm, drop)
-}
-
-fprodlCpp <- function(x, ng = 0L, g = 0L, w = NULL, narm = TRUE, drop = TRUE) {
-    .Call(Cpp_fprodl, x, ng, g, w, narm, drop)
+fnthlCpp <- function(x, n = 0.5, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE, drop = TRUE, ret = 1L, nthreads = 1L) {
+  .Call(Cpp_fnthl, x, n, ng, g, gs, w, narm, drop, ret, nthreads)
 }
 
 fscaleCpp <- function(x, ng = 0L, g = 0L, w = NULL, narm = TRUE, set_mean = 0, set_sd = 1) {
@@ -159,18 +113,10 @@ fscalelCpp <- function(x, ng = 0L, g = 0L, w = NULL, narm = TRUE, set_mean = 0,
     .Call(Cpp_fscalel, x, ng, g, w, narm, set_mean, set_sd)
 }
 
-fsumC <- function(x, ng = 0L, g = 0L, w = NULL, narm = TRUE) {
-    .Call(C_fsum, x, ng, g, w, narm)
+fsumC <- function(x, ng = 0L, g = 0L, w = NULL, narm = TRUE, nthreads = 1L) {
+    .Call(C_fsum, x, ng, g, w, narm, nthreads)
 }
 
-# fsummC <- function(x, ng = 0L, g = 0L, w = NULL, narm = TRUE, drop = TRUE) {
-#     .Call(C_fsumm, x, ng, g, w, narm, drop)
-# }
-
-# fsumlC <- function(x, ng = 0L, g = 0L, w = NULL, narm = TRUE, drop = TRUE) {
-#     .Call(C_fsuml, x, ng, g, w, narm, drop)
-# }
-
 fvarsdCpp <- function(x, ng = 0L, g = 0L, gs = NULL, w = NULL, narm = TRUE, stable_algo = TRUE, sd = TRUE) {
     .Call(Cpp_fvarsd, x, ng, g, gs, w, narm, stable_algo, sd)
 }
@@ -207,8 +153,8 @@ qFCpp <- function(x, ordered = TRUE, na_exclude = TRUE, keep_attr = TRUE, ret =
   .Call(Cpp_qF, x, ordered, na_exclude, keep_attr, ret)
 }
 
-funiqueCpp <- function(x, sort = TRUE) {
-    .Call(Cpp_funique, x, sort)
+sortuniqueCpp <- function(x) {
+    .Call(Cpp_sortunique, x)
 }
 
 fdroplevelsCpp <- function(x, check_NA = TRUE) {
