@@ -8,8 +8,15 @@ roworder <- function(X, ..., na.last = TRUE) {
   o <- .Call(C_radixsort, na.last, dec, FALSE, FALSE, TRUE, z)
   if(!is.na(na.last) && attr(o, "sorted")) return(condalc(X, inherits(X, "data.table")))
   rn <- attr(X, "row.names")
-  if(is.numeric(rn) || is.null(rn) || rn[1L] == "1") return(.Call(C_subsetDT, X, o, seq_along(unclass(X)), FALSE))
-  return(`attr<-`(.Call(C_subsetDT, X, o, seq_along(unclass(X)), FALSE), "row.names", rn[o]))
+  res <- .Call(C_subsetDT, X, o, seq_along(unclass(X)), FALSE)
+  if(!(is.numeric(rn) || is.null(rn) || rn[1L] == "1")) attr(res, "row.names") <- Csv(rn, o)
+  if(inherits(X, "pdata.frame")) {
+    index <- findex(X)
+    index_o <- .Call(C_subsetDT, index, o, seq_along(unclass(index)), FALSE)
+    if(inherits(X, "indexed_frame")) return(reindex(res, index_o))
+    attr(res, "index") <- index_o
+  }
+  res
 }
 
 posord <- function(sq, o, pos) switch(pos,
@@ -42,15 +49,22 @@ roworderv <- function(X, cols = NULL, neworder = NULL, decreasing = FALSE, na.la
     if(length(neworder) != fnrow2(X)) neworder <- posord(seq_along(.subset2(X, 1L)), neworder, pos)
   }
   rn <- attr(X, "row.names")
-  if(is.numeric(rn) || is.null(rn) || rn[1L] == "1") return(.Call(C_subsetDT, X, neworder, seq_along(unclass(X)), FALSE))
-  return(`attr<-`(.Call(C_subsetDT, X, neworder, seq_along(unclass(X)), FALSE), "row.names", rn[neworder]))
+  res <- .Call(C_subsetDT, X, neworder, seq_along(unclass(X)), FALSE)
+  if(!(is.numeric(rn) || is.null(rn) || rn[1L] == "1")) attr(res, "row.names") <- Csv(rn, neworder)
+  if(inherits(X, "pdata.frame")) {
+    index <- findex(X)
+    index_neworder <- .Call(C_subsetDT, index, neworder, seq_along(unclass(index)), FALSE)
+    if(inherits(X, "indexed_frame")) return(reindex(res, index_neworder)) # pdata.frame cannot be data.table...
+    attr(res, "index") <- index_neworder
+  }
+  res
 }
 
-colorder <- function(X, ..., pos = "front") { # This also takes names and indices ....
-  ax <- attributes(X)
-  oldClass(X) <- NULL # attributes ?
-  nam <- names(X)
-  iX <- seq_along(X)
+colorder <- function(.X, ..., pos = "front") { # This also takes names and indices ....
+  ax <- attributes(.X)
+  oldClass(.X) <- NULL # attributes ?
+  nam <- names(.X)
+  iX <- seq_along(.X)
   nl <- `names<-`(as.vector(iX, "list"), nam)
   vars <- eval(substitute(c(...)), nl, parent.frame())
   if(!is.integer(vars)) stop(paste0("Unknown columns: ", .c(...)))
@@ -60,7 +74,7 @@ colorder <- function(X, ..., pos = "front") { # This also takes names and indice
     nam[vars[nonmiss]] <- nam_vars[nonmiss]
   }
   if(length(vars) != length(iX)) vars <- posord(iX, vars, pos)
-  return(condalcSA(X[vars], `[[<-`(ax, "names", nam[vars]),
+  return(condalcSA(.X[vars], `[[<-`(ax, "names", nam[vars]),
                    any(ax[["class"]] == "data.table")))
 }
 
